autowisp.database.data_model.provenance.observatory module — AutoWISP documentation

# autowisp.database.data_model.provenance.observatory module

## Class Inheritance Diagram

Define the observatory dataset table for the pipeline

class autowisp.database.data_model.provenance.observatory.Observatory(**kwargs)

  Bases: `DataModelBase`

  The table describing the observatory

  __str__()

    Human readable identifier for the observatory.

  altitude

    The altitude of the observatory

  id

    A unique identifier for each row.

  latitude

    The latitude of the observatory

  longitude

    The longitude of the observatory

  name

    The name of the observatory

  observing_sessions
  timestamp

    When record was last changed